@@ -113,7 +113,8 @@ class Pipeline(ABC):
             logger.debug(f"executing component of type {s['type']} ")
             _component = s['component']
             if s['type'] == 'spacy':
-                out = list(_component.pipe(input, as_tuples=True, n_process=-1))
+                nlp :Language = s['component']
+                out = list(nlp.pipe(input, as_tuples=True, n_process=-1))
                 input = out
             else:
                 out = _component(input)
@@ -223,7 +224,7 @@ class Pipeline(ABC):
         return pipe_stack
 
     def init_spacy_nlp(self, subpipeline) -> Language:
-        nlp =  spacy.blank("en")#spacy.load(self.spacy_language_model, exclude=["tok2vec", "tagger", "parser", "attribute_ruler", "lemmatizer", "ner"])
+        nlp:Language =  spacy.blank("en")#spacy.load(self.spacy_language_model, exclude=["tok2vec", "tagger", "parser", "attribute_ruler", "lemmatizer", "ner"])
         for pipe in subpipeline:
             if not nlp.has_pipe(pipe.pipe_id_or_func):
                 if pipe.pipe_id_or_func in nlp.disabled:
